@@ -1,2 +1,2 @@
 from .modules import * 
-from .utils import * 
\ No newline at end of file
+from . import utils 
\ No newline at end of file
